aboutsummaryrefslogtreecommitdiff
path: root/bash/bash_completion.d
diff options
context:
space:
mode:
Diffstat (limited to 'bash/bash_completion.d')
-rw-r--r--bash/bash_completion.d/eds.bash (renamed from bash/bash_completion.d/vis.bash)14
1 files changed, 7 insertions, 7 deletions
diff --git a/bash/bash_completion.d/vis.bash b/bash/bash_completion.d/eds.bash
index f84cb702..8d0f6067 100644
--- a/bash/bash_completion.d/vis.bash
+++ b/bash/bash_completion.d/eds.bash
@@ -1,15 +1,15 @@
# Complete args to vis(1) with existing executables in $VISPATH, defaulting to
# ~/.local/bin
-_vis() {
- local vispath
- vispath=${VISPATH:-"$HOME"/.local/bin}
- [[ -d $vispath ]] || return
+_eds() {
+ local edspath
+ edspath=${EDSPATH:-"$HOME"/.local/bin}
+ [[ -d $edspath ]] || return
while IFS= read -rd '' executable ; do
COMPREPLY[${#COMPREPLY[@]}]=$executable
done < <(
shopt -s dotglob nullglob
declare -a files
- files=("${VISPATH:-"$HOME"/.local/bin}"/"${COMP_WORDS[COMP_CWORD]}"*)
+ files=("${EDSPATH:-"$HOME"/.local/bin}"/"${COMP_WORDS[COMP_CWORD]}"*)
declare -a executables
for file in "${files[@]}" ; do
[[ -f $file && -x $file ]] || continue
@@ -19,4 +19,4 @@ _vis() {
printf '%q\0' "${executables[@]}"
)
}
-complete -F _vis vis
+complete -F _eds eds
@@ -1,15 +1,15 @@
-# Complete args to vis(1) with existing executables in $VISPATH, defaulting to
+# Complete args to eds(1) with existing executables in $EDSPATH, defaulting to
# ~/.local/bin